@@ -1,4 +1,4 @@
-# $Id: crt.py 899 2014-05-03 12:30:06Z mwall $
+# $Id: crt.py 924 2014-06-03 11:48:08Z mwall $
 # Copyright 2013 Matthew Wall
 
 # Emit loop data to file in Cumulus realtime format.
@@ -145,6 +145,8 @@ def calcWindRun(archive, ts):
 
 # calculate trend over past n hours, default to 3 hour window
 def calcTrend(label, new_val, archive, ts, n=3):
+    if new_val is None:
+        return None
     lastts = ts - n * 3600
     qstr = "SELECT %s FROM archive WHERE dateTime>? AND dateTime<=?" % label
     old_val = archive.getSql(qstr, (lastts, ts))
@@ -196,6 +198,8 @@ def calcMinMax(label, archive, ts, minmax='MAX'):
     return val[0],tstr
 
 def calcHumidex(t_C, dewpoint_K):
+    if t_C is None or dewpoint_K is None:
+        return None
     v = 1/273.16
     v -= 1/dewpoint_K
     v *= 5417.7530
@@ -226,6 +230,8 @@ def calcDaylightHours(ts_utc, lat, lon):
     return (sunset_utc - sunrise_utc) / 60
 
 def calcCloudBase(outTemp_F, dewpoint_F, altitude_foot):
+    if outTemp_F is None or dewpoint_F is None:
+        return None
     return int((outTemp_F - dewpoint_F) / 4.4 * 1000) + altitude_foot
 
 # this depends on the weather station
